![Stylist CI](https://github.com/renderbox/django-stylist/workflows/Stylist%20CI/badge.svg)

![Stylist Develop](https://github.com/renderbox/django-stylist/workflows/Stylist%20Develop/badge.svg)

# Stylist

App for updating and manipulating SASS/SCSS compiling on the fly
